# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE


import gst
#needed to get pulseaudio dataz
import commands
import gobject
import tempfile

from tibesti import Options

class AudioPipeline(gobject.GObject):
    __gtype_name__ = 'AudioPipeline'
    def __new__(cls,*args,**kwargs):
        options = Options.OptionsStore()
        if options.get_seperate_streams():
            for subcls in cls.__subclasses__():
                if gobject.type_name(subcls) == 'SeperateAudioPipeline':
                    if options.get_audio_out() and options.get_microphone():
                        for subsubcls in subcls.__subclasses__():
                            if gobject.type_name(subsubcls) == "SeperateMultiAudioPipeline":
                                cls = subsubcls
                    elif options.get_audio_out():
                        for subsubcls in subcls.__subclasses__():
                            if gobject.type_name(subsubcls) == "SeperateAudioOutPipeline":
                                cls = subsubcls
                    elif options.get_microphone():
                        for subsubcls in subcls.__subclasses__():
                            if gobject.type_name(subsubcls) == "SeperateMicPipeline":
                                cls = subsubcls  
        elif options.get_audio_out() and options.get_microphone():
            for subcls in cls.__subclasses__():
                if gobject.type_name(subcls)=="MultiAudioPipeline":
                    cls = subcls
        elif options.get_audio_out():
            for subcls in cls.__subclasses__():
                if gobject.type_name(subcls)=="AudioOutPipeline":
                    cls = subcls        
        elif options.get_microphone():
            for subcls in cls.__subclasses__():
                if gobject.type_name(subcls)=="MicrophonePipeline":
                    cls = subcls
        else:
            pass
        return super(AudioPipeline,cls).__new__(cls,*args,**kwargs)

    def __init__(self):
        self.options = Options.OptionsStore()
    
    def speaker_source(self):
        #get the current audio output
        pulse_input = commands.getoutput('pactl stat | grep "Sink" | cut -d" " -f3')+'.monitor'
        return 'pulsesrc device=%s name=audiopipe' % (pulse_input)      
    
    def microphone_source(self):
        pulse_mic = commands.getoutput('pactl stat | grep "Source" | cut -d" " -f3')
        return 'pulsesrc device=%s name=micpipe' % (pulse_mic)

    def filters(self):
        return 'audioresample ! audioconvert'
        
    def encoder(self):
        return self.options.get_audio_encoder()
    
    #each version implements this, but it is empty here for a reminder
    def audio(self):
        pass


class MultiAudioPipeline(AudioPipeline):
    __gtype_name__ = 'MultiAudioPipeline'
    pass

    def filters(self):
        return 'audioresample ! audioconvert ! inter.'
        
    def audio(self):
        speakers = '%s ! %s' % (self.speaker_source(),self.filters())
        mic = '%s ! %s' % (self.microphone_source(),self.filters())
        inter = 'adder name=inter ! audioconvert ! %s' % (self.encoder())
        return ('%s ! mux. %s %s' % (inter,speakers, mic))

class AudioOutPipeline(AudioPipeline):
    __gtype_name__ = 'AudioOutPipeline'
    
    def audio(self):
        return '%s ! %s ! %s ! mux.' % (self.speaker_source(),self.filters(),self.encoder())

class MicrophonePipeline(AudioPipeline):
    __gtype_name__ = 'MicrophonePipeline'

    def audio(self):
        return '%s ! %s ! %s ! mux.' % (self.microphone_source(),self.filters(),self.encoder())

class SeperateAudioPipeline(AudioPipeline):
    __gtype_name__ = 'SeperateAudioPipeline'
    
    def __new__(cls,*args,**kwargs):
        options = Options.OptionsStore()
        if options.get_audio_out() and options.get_microphone():
            for subcls in cls.__subclasses__():
                if gobject.type_name() == "SeperateMultiAudioPipeline":
                    cls = subcls
        if options.get_audio_out():
            for subcls in cls.__subclasses__():
                if gobject.type_name() == "SeperateAudioOutPipeline":
                    cls = subcls
        if options.get_microphone():
            for subcls in cls.__subclasses__():
                if gobject.type_name() == "SeperateMicPipeline":
                    cls = subcls            
        return super(SeperateAudioPipeline,cls).__new__(cls,*args,**kwargs)        

    def filesink_create(self):
        temporary_directory = self.options.get_temporary_dir()
        temp_file = tempfile.mkstemp(dir=temporary_directory)[1]
        return temp_file
    
    def filters(self):
        return 'audioresample ! audioconvert ! queue'
        
    def encoder(self):
        return "vorbisenc ! oggmux ! filesink location="
        
    def get_temp_files(self):
        return self.file_sink
        
class SeperateAudioOutPipeline(SeperateAudioPipeline):
    __gtype_name__ = "SeperateAudioOutPipeline"

    def audio(self):
        speakers = '%s ! %s' % (self.speaker_source(),self.filters())
        self.file_sink = [self.filesink_create()]
        encoder = self.encoder() + self.file_sink[0]
        return speakers + ' ! ' + encoder

class SeperateMicPipeline(SeperateAudioPipeline):
    __gtype_name__ = "SeperateMicPipeline"

    def audio(self):
        speakers = '%s ! %s' % (self.microphone_source(),self.filters())
        self.file_sink = [self.filesink_create()]
        encoder = self.encoder() + self.file_sink[0]
        return speakers + ' ! ' + encoder
        
class SeperateMultiAudioPipeline(SeperateAudioPipeline):
    __gtype_name__ = "SeperateMultiAudioPipeline"

    def audio(self):
        speakers = '%s ! %s' % (self.speaker_source(),self.filters())
        mic = '%s ! %s' % (self.microphone_source(),self.filters())
        self.file_sink = [self.filesink_create(),self.filesink_create()]
        speakers += ' ! ' + self.encoder() + self.file_sink[0]
        mic += ' ! ' + self.encoder() + self.file_sink[1]
        return (speakers,mic)
