# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

import os
import ConfigParser

class ConfigStore:
	def __init__(self,default_values):
        #our config file :]
        self.config_file = os.environ['HOME'] + '/.config/tibesti/tibesti.ini'
        
        #get some defaults
        self.options=default_values
        self.config_store = ConfigParser.SafeConfigParser()

        #if we don't have a config file yet
        if not os.path.exists(self.config_file):
            self._create_preferences()
        if self.config_store.read(self.config_file) == []:
            self._create_preferences()
        
    def get_preferences(self):
        #returns a dictionary of the preferences
        for option in self.config_store.options('General'):
            self.options[option]=self.config_store.get('General',option)
        return self.options
        
    def save_preferences(self,new_options):
        #set each option in self.options from the passed options
        for option in new_options:
            self.options[option] = new_options[option]
        #saves the preferences to the ini file
        if not self.config_store.has_section('General'):
            self.config_store.add_section('General')
        #set config_store up with passed options 
        for key in self.options:
            self.config_store.set('General',key,str(new_options[key]))
            
        #write out our options
        cf = open(self.config_file,'w')
        self.config_store.write(cf)
    
    def _create_preferences(self):
        if not os.path.exists(os.environ['HOME']+'/.config/'):
            os.mkdir(os.environ['HOME']+'/.config/',0700)
        if not os.path.exists(os.environ['HOME']+'/.config/tibesti/'):
            os.mkdir(os.environ['HOME']+'/.config/tibesti/',0700)
        self.save_preferences(self.options)
        
