# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

from tibesti.IniStore import ConfigStore
from tibesti.Preset import PresetManager
import os

class OptionsStore:
	initialized = False
	changed = False
    default_prefs = {
		"quality":2,
		"audio_out":'True',
		"microphone":'True',
		"include_pointer":'False',
		"seperate_streams":'False',
		"temporary_dir":'/tmp/',
		"save_dir":os.environ['HOME'],
		"recording_delay":0,
		"preset_num":1
		}

	def __init__(self):
		self.options_conn = ConfigStore(self.default_prefs)
        if not OptionsStore.initialized:
            self.load_from_store()

    def load_from_store(self):
        self.preferences = self.options_conn.get_preferences()
        self.set_quality(int(self.preferences['quality']))
        self.set_audio_out(self.preferences['audio_out']=="True")
        self.set_microphone(self.preferences['microphone']=="True")
        self.set_include_pointer(self.preferences['include_pointer']=="True")
        self.set_seperate_streams(self.preferences['seperate_streams']=="True")
        self.set_temporary_dir(self.preferences['temporary_dir'])
        self.set_save_dir(self.preferences['save_dir'])
        self.set_recording_delay(int(self.preferences['recording_delay']))
        self.set_capture_type('fullscreen')
        self.set_preset_num(int(self.preferences['preset_num']))
        self.set_capture_type('fullscreen')
        self.load_preset(self.get_preset_num())
        OptionsStore.initialized = True
        OptionsStore.changed = False
        
    def save_to_store(self):
		if not OptionsStore.changed:
			return
        self.preferences=dict()
        self.preferences['quality'] = self.get_quality()
        self.preferences['audio_out'] = str(self.get_audio_out())
        self.preferences['microphone'] = str(self.get_microphone())
        self.preferences['include_pointer'] = str(self.get_include_pointer())
        self.preferences['seperate_streams'] = str(self.get_seperate_streams())
        self.preferences['temporary_dir'] = self.get_temporary_dir()
        self.preferences['save_dir'] = self.get_save_dir()
        self.preferences['recording_delay'] = self.get_recording_delay()
        self.preferences['preset_num'] = self.get_preset_num()
        self.options_conn.save_preferences(self.preferences)

	def load_preset(self,preset_num):
		pm = PresetManager()
		preset = pm.load_preset(preset_num)
		self.set_container(preset['mux'])
		self.set_video_encoder(preset['video_encoder'])
		self.set_audio_encoder(preset['audio_encoder'])
        self.set_preset_desc(preset['desc'])
        self.set_mime_type(preset['mime'])

    def get_container(self):
        return OptionsStore.container
    def set_container(self,new_container):
        OptionsStore.container=new_container

    def get_video_encoder(self):
        return OptionsStore.video_encoder
    def set_video_encoder(self,new_video_encoder):
        OptionsStore.video_encoder=new_video_encoder

    def get_audio_encoder(self):
        return OptionsStore.audio_encoder
    def set_audio_encoder(self,new_audio_encoder):
        OptionsStore.audio_encoder=new_audio_encoder

    def get_quality(self):
        return OptionsStore.quality
    def set_quality(self,new_quality):
        OptionsStore.quality=new_quality        
        OptionsStore.changed = True

    def get_audio_out(self):
        return OptionsStore.audio_out
    def set_audio_out(self,new_audio_out):
        OptionsStore.audio_out=new_audio_out
        OptionsStore.changed = True

    def get_microphone(self):
        return OptionsStore.microphone
    def set_microphone(self,new_microphone):
        OptionsStore.microphone=new_microphone       
        OptionsStore.changed = True

    def get_include_pointer(self):
        return OptionsStore.include_pointer
    def set_include_pointer(self,new_include_pointer):
        OptionsStore.include_pointer=new_include_pointer 
        OptionsStore.changed = True

    def get_seperate_streams(self):
        return OptionsStore.separate_streams
    def set_seperate_streams(self,new_seperate_streams):
        OptionsStore.separate_streams =new_seperate_streams
        OptionsStore.changed = True

    def get_temporary_dir(self):
        return OptionsStore.temporary_dir
    def set_temporary_dir(self,new_temporary_dir):
        OptionsStore.temporary_dir=new_temporary_dir
        OptionsStore.changed = True

    def get_save_dir(self):
        return OptionsStore.save_dir
    def set_save_dir(self,new_save_dir):
        OptionsStore.save_dir=new_save_dir        
        OptionsStore.changed = True

    def get_recording_delay(self):
        return OptionsStore.recording_delay
    def set_recording_delay(self,new_recording_delay):
        OptionsStore.recording_delay=new_recording_delay
        OptionsStore.changed = True

    def get_capture_type(self):
        return OptionsStore.capture_type
    def set_capture_type(self,new_capture_type):
        OptionsStore.capture_type=new_capture_type  
        OptionsStore.changed = True

    def get_capture_area(self):
        return OptionsStore.capture_area
    def set_capture_area(self,new_capture_area):
        OptionsStore.capture_area=new_capture_area
        OptionsStore.changed = True        

    def get_preset_num(self):
        return OptionsStore.preset_num
    def set_preset_num(self,new_preset_num):
        OptionsStore.preset_num=new_preset_num
        OptionsStore.changed = True

    def get_preset_desc(self):
        return OptionsStore.preset_desc
    def set_preset_desc(self,new_preset_desc):
        OptionsStore.preset_desc=new_preset_desc
        OptionsStore.changed = True

    def get_mime_type(self):
        return OptionsStore.mime_type
    def set_mime_type(self,new_mime_type):
        OptionsStore.mime_type=new_mime_type
