# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

#needed to find ximagesrc information
import gtk
#gstreamer, for recording
import gst
#for copying files
import gnomevfs
#make temporary files for saving
import tempfile


from tibesti import Options

#encoder optimizations are split out into their own class
from tibesti import EncoderOptions

#audio and video capture can be complex, so they're split into their own classes
from tibesti import AudioPipeline,VideoPipeline

def PipelineFactory():
    options = Options.OptionsStore()
    container = options.get_container()
    if container == 'ogg':
        return OggPipeline()
    elif container == 'matroska':
        return MatroskaPipeline()
    elif container == 'avi':
        return AviPipeline()
    elif container == "webm":
        return WebmPipeline()
    elif container == 'flv':
        return FlvPipeline()


class Pipeline(object):
    
	ext = 4

    profiles = {4:{'level':4,'name':'Very Low','framerate':'6'},
    3:{'level':3,'name':'Low','framerate':'10'},
    2:{'level':2,'name':'Default','framerate':'15'}, 
    1:{'level':1,'name':'High','framerate':'20'}, 
    0:{'level':0,'name':'Very High','framerate':'30'}
    }
    def __init__(self):
        self.options = Options.OptionsStore()

    def start_pipeline(self):
		pipe = self.assemble_pipeline()
		print pipe
        self.pipeline = gst.parse_launch(pipe)
        self.video_pipe = self.pipeline.get_by_name("videopipe")
        if self.options.get_audio_out():
            self.audio_pipe = self.pipeline.get_by_name("audiopipe")
        if self.options.get_microphone():
            self.mic_pipe = self.pipeline.get_by_name("micpipe")
        self.pipeline_bus = self.pipeline.get_bus()
        self.pipeline_bus.add_signal_watch()
        self.pipeline_bus.connect("message", self.bus_message_cb)
        self.pipeline.set_state(gst.STATE_PLAYING)
    
    def bus_message_cb(self,bus,message):
        if message.type == gst.MESSAGE_EOS or message.type == gst.MESSAGE_CLOCK_LOST:
            self.pipeline.set_state(gst.STATE_NULL)

        
    def stop_pipeline(self):
        self.video_pipe.set_state(gst.STATE_NULL)
        self.video_pipe.set_locked_state(True)
        if self.options.get_audio_out():
            self.audio_pipe.set_state(gst.STATE_NULL)
            self.audio_pipe.set_locked_state(True)
        if self.options.get_microphone():
            self.mic_pipe.set_state(gst.STATE_NULL)
            self.mic_pipe.set_locked_state(True)


    def save_pipeline(self,file_uri):
		def move_file(temp_file_uri, final_file_uri):
			try:
				result = gnomevfs.xfer_uri(
                    gnomevfs.URI('file://%s'% (temp_file_uri)),
                    gnomevfs.URI(final_file_uri),
                    gnomevfs.XFER_REMOVESOURCE,
                    gnomevfs.XFER_ERROR_MODE_ABORT,
                    gnomevfs.XFER_OVERWRITE_MODE_REPLACE)
			except:
				print "Could not move file, perhaps it was deleted"
		def make_final_uris(user_file_uri):
			return_array = ['video_uri','audio_uri','microphone_uri','speaker_uri']
            
            #checks if the user already appended a valid extension
			if len(user_file_uri) >= self.ext and user_file_uri[len(user_file_uri)-self.ext:] in self.valid_endings:
				base = user_file_uri[:len(user_file_uri)-self.ext]
				ending = user_file_uri[len(user_file_uri)-self.ext:]
			else:
				base = user_file_uri
				ending = self.valid_endings[0]
			return_array[0] = base+ending
			return_array[1] = base+'-audio.ogg'
			return_array[2] = base+'-microphone.ogg'
			return_array[3] = base+'-speakers.ogg'
			return return_array
		
		file_names = make_final_uris(file_uri)
        self.final_names=list()
		move_file(self.video_temp,file_names[0])
        self.final_names.append(file_names[0])
		if self.options.get_seperate_streams():
			if self.options.get_audio_out() ^ self.options.get_microphone():
				move_file(self.audio_temp,file_names[1])
                self.final_names.append(file_names[1])
			if self.audio_out and self.microphone:
                move_file(self.mic_temp,file_names[2])
				move_file(self.speakers_temp,file_names[3])
                self.final_names.append(file_names[2])
                self.final_names.append(file_names[3])

    def get_final_files(self):
        return self.final_names
        
    def delete_files(self):
        gnomevfs.unlink(gnomevfs.URI('file://'+self.video_temp))
        try:
            fn = 'file://' + self.audio_temp
            gnomevfs.unlink(gnomevfs.URI(fn))
        except:
            pass
        try:
            fn = 'file://' + self.speakers_temp
            gnomevfs.unlink(gnomevfs.URI(fn))
        except:
            pass
        try:
            fn = 'file://' + self.mic_temp
            gnomevfs.unlink(gnomevfs.URI(fn))
        except:
            pass                        

    def assemble_pipeline(self):
        def mux_create(a_v):
            if a_v == 'video':
                return self.muxer
            if (self.options.get_audio_out() and self.options.get_microphone()) and (not self.options.get_seperate_streams()):
                base = 'interleave name=inter ! audioconvert ! '
                return base + self.options.get_audio_encoder()
            return self.muxer
        def filesink_create(sink_type):
            self.temporary_directory = self.options.get_temporary_dir()
            if sink_type == 'audio':
                self.audio_temp = tempfile.mkstemp(dir=self.temporary_directory)[1]
                return 'filesink location=' + self.audio_temp
            if sink_type == 'speakers':
                self.speakers_temp = tempfile.mkstemp(dir=self.temporary_directory)[1]
                return 'filesink location=' + self.speakers_temp
            if sink_type == 'mic':
                self.mic_temp = tempfile.mkstemp(dir=self.temporary_directory)[1]
                return 'filesink location=' + self.mic_temp
            if sink_type == 'video':
                self.video_temp = tempfile.mkstemp(dir=self.temporary_directory)[1]
                return 'filesink location=' + self.video_temp
        
        #create sub-pipelines
        self.audio_system = AudioPipeline.AudioPipeline()
        self.video_system = VideoPipeline.VideoPipeline()
        
        #start actual assembly
        if self.options.get_seperate_streams():
            base = self.video_system.video() + ' ! ' + mux_create('video') + ' ! ' + filesink_create('video')  + ' '
            audio_streams = self.audio_system.audio()
            if (self.options.get_audio_out() ^ self.options.get_microphone()):
                base += audio_streams + ' ! ' + filesink_create('audio')
            elif (self.options.get_audio_out() and self.options.get_microphone()):
                base += audio_streams[0] + ' ! oggmux ! ' + filesink_create('speakers')
                base += ' ' + audio_streams[1] + ' ! oggmux ! ' + filesink_create('mic')
        else:
            if (not self.options.get_audio_out() and not self.options.get_microphone()):
                return self.video_system.video() + ' ! ' + mux_create('video') + ' ! ' + filesink_create('video')
            base = mux_create('video') + ' name=mux ! ' + filesink_create('video') + ' ' + self.video_system.video() + ' ! mux. ' + self.audio_system.audio()
        return base    
        
class OggPipeline(Pipeline):
    muxer = "oggmux"
    allowed_enc = {"audio":["vorbisenc","flacenc"],"video":["theoraenc"]}
    current_encoder = {"audio":"vorbisenc","video":"theoraenc"}
    valid_endings = ['.ogg']
class MatroskaPipeline(Pipeline):
    muxer="matroskamux"
    allowed_enc = {"audio":["vorbisenc","flacenc"],"video":["theoraenc","x264enc","xvidenc",'ffenc_huffyuv']}
    current_encoder = {'audio':'vorbisenc','video':'x264enc'}
    valid_endings = ['.mkv']
class AviPipeline(Pipeline):
    muxer="avimux"
    allowed_enc = {"audio":["lamemp3enc"],"video":["xvidenc","ffenc_huffyuv"]}  
    current_encoder = {"audio":'lamemp3enc','video':'xvidenc'}
    valid_endings = ['.avi']
class WebmPipeline(Pipeline):
    muxer="webmmux"
    ext = 5
    allowed_enc = {"audio":["vorbisenc"],"video":["vp8enc"]}
    current_encoder = {"audio":"vorbisenc","video":"vp8enc"}
    valid_endings = ['.webm']        
class FlvPipeline(Pipeline):
    muxer="flvmux"
    allowed_enc = {"audio":["lamemp3enc"],"video":["x264enc"]}
    current_encoder = {'audio':"lamemp3enc",'video':"x264enc"}
    valid_endings = ['.flv']
