# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

#STATES
STATE_IDLE = 1
STATE_RECORDING = 2
STATE_SAVING = 3
import gtk,glib
import gio
from tibesti import Options,SaveDialog,ZeitgeistConnection,indicator,Pipeline,PreferencesTibestiDialog

class PipelineController:
    def __init__(self):
        self.options = Options.OptionsStore()
        self.zeitgeist = ZeitgeistConnection.ZeitgeistConnection()
		#TODO move to init class
        if indicator:
            self.indicator = indicator.new_application_indicator(self)   
        self.state = STATE_IDLE

    def start_recording(self,data=None):
        if self.state == STATE_IDLE:
			self.state = STATE_RECORDING
            print self.state
			self.pipeline = Pipeline.PipelineFactory()
			self.pipeline.start_pipeline()
		else:
			print "error, start recording called when state != idle"
			
        
    def stop_recording(self):
        if self.state == STATE_RECORDING:
			self.state = STATE_SAVING
			self.pipeline.stop_pipeline()
			self._save_dialog()
		else:
			print "error, stop recording called when state != recording"
	    
	def _save_dialog(self):
		if self.state == STATE_SAVING:
            
			dialog = SaveDialog.SaveDialog()
            dialog.set_name(self.pipeline.valid_endings[0])
			result = dialog.run()
            
			if result == gtk.RESPONSE_OK:
				self.save_file = dialog.get_save_file()
                dialog.destroy()

                if self._check_dest_and_file():
                    self.options.set_save_dir(self.save_file.rsplit('/',1)[0]+'/')
                    self._save_pipeline(self.save_file)
                else:
                    self.pipeline.delete_files()
                    
			else:
				self.pipeline.delete_files()
                dialog.destroy()

                
            self.main_window.record_button_toggle()
            self.state=STATE_IDLE
    def _resave_dialog(self):
        dialog = SaveDialog.SaveDialog()
        dialog.set_full_name(self.save_file.rsplit('/',1)[1])
        result=dialog.run()
        
        if result == gtk.RESPONSE_OK:
            self.save_file = dialog.get_save_file()
            dialog.destroy()
            df = self._check_dest_and_file()
            print df
            return df
        
        else:
            dialog.destroy()
            return False

    def _check_dest_and_file(self):
        #originally I was going to check to see if a file existed (overwriting)
        #on further thinking, asking would be patronizing, as I changed the
        #automatic name to be unique as opposed to 1 default
        
        #check the folder, if it's True, we've got a good folder, it'll also let the user
        #choose a new folder, recursively until he/she gets a writable one
        if self._check_folder():
            return True
        else:
            return False

            

    def _check_folder(self):
        save_dir = self.save_file.rsplit('/',1)[0]+'/'
        dir_info = gio.File(save_dir).query_info('access::can-write')
        if dir_info.get_attribute_boolean('access::can-write'):
            return True
        else:
            return self._ask_change_folder()
                       
   
    def _ask_change_folder(self):
        dlg = gtk.MessageDialog(
            None,
            gtk.DIALOG_MODAL,
            gtk.MESSAGE_WARNING,
            gtk.BUTTONS_YES_NO,
            """I can't save the file where you wanted.
            Would you like to Save to another location?
            NOTE: If you select No, your recording will be deleted!"""
            )
        dlg.set_title("Tibesti Save Error")

        response = dlg.run()
        if response == gtk.RESPONSE_YES:
            dlg.destroy()
            return self._resave_dialog()
        dlg.destroy()
        return False
	def _save_pipeline(self,save_file_name):
		self.pipeline.save_pipeline('file://'+save_file_name)
		self._log_pipeline()
		
	def _log_pipeline(self):
		save_file_uris = self.pipeline.get_final_files()
		if len(save_file_uris) == 1:
			mime_type = self.options.get_mime_type()
			self.zeitgeist.log_video(save_file_uris[0],mime_type)
		else:
			#TODO build seperate audio and video mime types
			mime_type = self.options.get_mime_type()
			save_uris_and_mime = []
			for uri in save_file_uris:
				save_uris_and_mime.append((uri,mime_type))
			self.zeitgeist.log_multi(save_uris_and_mime)
	
	def get_status(self):
		return self.state

    def preferences(self,widget,data=None):
        dlg=PreferencesTibestiDialog.PreferencesTibestiDialog()
        response = dlg.run()
        dlg.destroy()
        
    def quit(self,widget,data=None):
        self.options.save_to_store()
        gtk.main_quit()
    
    def record_toggle(self,*data):
        if self.state == STATE_IDLE:
            self.main_window.record_button_toggle()
            self.indicator.countdown(self.options.get_recording_delay())
            glib.timeout_add(self.options.get_recording_delay()*1000,self.start_recording)
        elif self.state == STATE_RECORDING:
            self.main_window.record_button_toggle()
            self.indicator.reset_icon()
            self.stop_recording()
        elif self.state == STATE_SAVING:
            pass
        
    
    def set_option(self,caller,option_name,new_option):
        print option_name
        print new_option
        
    def set_main_window(self,window):
        self.main_window = window
        window.connect("options_button",self.preferences)
        window.connect("record_button",self.record_toggle)
        window.connect("option_changed",self.set_option)
        window.connect("destroy",self.quit)
