import unittest
from tibesti import AudioPipeline,Options,VideoPipeline


class SeperateAOTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(True)
        self.options.set_microphone(False)
        self.options.set_audio_out(True)
        self.options.set_audio_encoder('vorbisenc')
        self.options.set_temporary_dir('/tmp/')
        self.options.save_to_store()
        
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        correct = 'pulsesrc device=alsa_output.pci-0000_00_07.0.analog-stereo.monitor name=audiopipe ! audioresample ! audioconvert ! queue ! vorbisenc ! oggmux ! filesink location=/tmp/tmp'
        output = self.audio_pipeline.audio()
        #strip the random temp name from the end
        self.output = output[:len(output)-6]
        self.assertEqual(correct,self.output,msg='\nExpected: %s\nFound:    %s' % (correct,output))
        
class SeperateMicTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(True)
        self.options.set_microphone(True)
        self.options.set_audio_out(False)
        self.options.set_audio_encoder('vorbisenc')
        self.options.set_temporary_dir('/tmp/')
        self.options.save_to_store()
        
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        correct = 'pulsesrc device=alsa_input.usb-Logitech_Logitech_USB_Microphone-00-Microphone.analog-mono name=micpipe ! audioresample ! audioconvert ! queue ! vorbisenc ! oggmux ! filesink location=/tmp/tmp'
        output = self.audio_pipeline.audio()
        #strip the random temp name from the end
        self.output = output[:len(output)-6]
        self.assertEqual(correct,self.output,msg='\nExpected: %s\nFound:    %s' % (correct,output))

class SeperateMultiTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(True)
        self.options.set_microphone(True)
        self.options.set_audio_out(True)
        self.options.set_audio_encoder('vorbisenc')
        self.options.set_temporary_dir('/tmp/')
        self.options.save_to_store()
        
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        print self.audio_pipeline
        correct1 = 'pulsesrc device=alsa_output.pci-0000_00_07.0.analog-stereo.monitor name=audiopipe ! audioresample ! audioconvert ! queue ! vorbisenc ! oggmux ! filesink location=/tmp/tmp'
        correct2 = 'pulsesrc device=alsa_input.usb-Logitech_Logitech_USB_Microphone-00-Microphone.analog-mono name=micpipe ! audioresample ! audioconvert ! queue ! vorbisenc ! oggmux ! filesink location=/tmp/tmp'
        output = self.audio_pipeline.audio()
        #strip the random temp name from the end
        self.output1 = output[0][:len(output[0])-6]
        self.output2 = output[1][:len(output[1])-6]
        self.assertEqual(correct1,self.output1,msg='\nExpected: %s\nFound:    %s' % (correct1,self.output1))
        self.assertEqual(correct2,self.output2,msg='\nExpected: %s\nFound:    %s' % (correct2,output[1]))

class AOTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(False)
        self.options.set_microphone(False)
        self.options.set_audio_out(True)
        self.options.set_audio_encoder('vorbisenc')
        self.options.save_to_store()
        
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        correct = 'pulsesrc device=alsa_output.pci-0000_00_07.0.analog-stereo.monitor name=audiopipe ! audioresample ! audioconvert ! vorbisenc ! mux.'
        output = self.audio_pipeline.audio()
        self.assertEqual(correct,output,msg='\nExpected: "%s"\nFound:    "%s"' % (correct,output))

class MicTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(False)
        self.options.set_microphone(True)
        self.options.set_audio_out(False)
        self.options.set_audio_encoder('vorbisenc')
        self.options.save_to_store()
        
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        correct = 'pulsesrc device=alsa_input.usb-Logitech_Logitech_USB_Microphone-00-Microphone.analog-mono name=micpipe ! audioresample ! audioconvert ! vorbisenc ! mux.'
        output = self.audio_pipeline.audio()
        self.assertEqual(correct,output,msg='\nExpected: %s\nFound:    %s' % (correct,output))

class InterleaveTest(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(False)
        self.options.set_microphone(True)
        self.options.set_audio_out(True)
        self.options.set_audio_encoder('vorbisenc')
        self.options.save_to_store()
                
    def testNumber(self):
        self.audio_pipeline = AudioPipeline.AudioPipeline()
        correct = 'adder name=inter ! audioconvert ! vorbisenc ! mux. pulsesrc device=alsa_output.pci-0000_00_07.0.analog-stereo.monitor name=audiopipe ! audioresample ! audioconvert ! inter. pulsesrc device=alsa_input.usb-Logitech_Logitech_USB_Microphone-00-Microphone.analog-mono name=micpipe ! audioresample ! audioconvert ! inter.'
        output = self.audio_pipeline.audio()
        self.assertEqual(correct,output,msg='\nExpected: %s\nFound:    %s' % (correct,output))

class VideoTest1(unittest.TestCase):
    def setUp(self):
        pass
                
    def testNumber(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(False)
        self.options.set_microphone(False)
        self.options.set_audio_out(False)
        self.options.set_include_pointer(True)
        self.options.set_preset_num(1)
        self.options.set_quality(1)
        self.options.save_to_store()
        self.video_pipeline = VideoPipeline.VideoPipeline()
        correct = 'ximagesrc name=videopipe display-name=:0.0 screen-num=0 use-damage=false startx=0 starty=0 endx=1360 endy=768 ! video/x-raw-rgb,framerate=20/1 ! videorate ! ffmpegcolorspace ! videoscale method=1 ! video/x-raw-yuv,width=1360,height=784,framerate=20/1 ! theoraenc quality=36 ! queue'
        output = self.video_pipeline.video()
        self.assertEqual(correct,output,msg='\nExpected: %s\nFound:    %s' % (correct,output))

class VideoTest2(unittest.TestCase):
    def setUp(self):
        self.options = Options.OptionsStore()
        self.options.set_seperate_streams(False)
        self.options.set_microphone(False)
        self.options.set_audio_out(False)
        self.options.set_capture_type('fullscreen')
        self.options.set_include_pointer(True)
        self.options.set_preset_num(5)
        self.options.set_quality(3)
        self.options.save_to_store()
                
    def testNumber(self):
        self.video_pipeline = VideoPipeline.VideoPipeline()
        correct = 'ximagesrc name=videopipe display-name=:0.0 screen-num=0 use-damage=false startx=0 starty=0 endx=1360 endy=768 ! video/x-raw-rgb,framerate=10/1 ! videorate ! ffmpegcolorspace ! videoscale method=1 ! video/x-raw-yuv,width=1360,height=784,framerate=10/1 ! x264enc speed-preset=superfast ! queue'
        output = self.video_pipeline.video()
        self.assertEqual(correct,output,msg='\nExpected: %s\nFound:    %s' % (correct,output))

if __name__ == '__main__':
    unittest.main()

