# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

import gtk
from tibesti import AboutTibestiDialog
from tibesti.helpers import get_builder
from tibesti.Options import OptionsStore
import gettext
from gettext import gettext as _
gettext.textdomain('tibesti')

class PreferencesTibestiDialog(gtk.Dialog):
    __gtype_name__ = "PreferencesTibestiDialog"
    preferences = {}

    def __new__(cls):
        """Special static method that's automatically called by Python when 
        constructing a new instance of this class.
        
        Returns a fully instantiated PreferencesTibestiDialog object.
        """
        builder = get_builder('PreferencesTibestiDialog')
        new_object = builder.get_object("preferences_tibesti_dialog")
        new_object.finish_initializing(builder)
        return new_object

    def finish_initializing(self, builder):
        """Called while initializing this instance in __new__

        finish_initalizing should be called after parsing the ui definition
        and creating a PreferencesTibestiDialog object with it in order to
        finish initializing the start of the new PerferencesTibestiDialog
        instance.
        
        Put your initialization code in here and leave __init__ undefined.
        """

        # Get a reference to the builder and set up the signals.
        self.builder = builder
        self.builder.connect_signals(self)

        # Set up options management
        self.options = OptionsStore()
        
        # update the preferences ui
        self.builder.get_object('include_pointer_check').set_active(self.options.get_include_pointer())
        self.builder.get_object('seperate_streams_check').set_active(self.options.get_seperate_streams())
        self.builder.get_object('microphone_check').set_active(self.options.get_microphone())
        self.builder.get_object('audio_out_check').set_active(self.options.get_audio_out())
		self.builder.get_object('delay_button').set_value(self.options.get_recording_delay())
		self.builder.get_object('temp_dir_entry').set_text(self.options.get_temporary_dir())
		self.builder.get_object('save_dir_entry').set_text(self.options.get_save_dir())

	def seperate_streams_handler(self,widget,data=None):
		self.options.set_seperate_streams(widget.get_active())
	def include_pointer_handler(self,widget,data=None):
		self.options.set_include_pointer(widget.get_active())
	def microphone_handler(self,widget,data=None):
		self.options.set_microphone(widget.get_active())
	def audio_out_handler(self,widget,data=None):
		self.options.set_audio_out(widget.get_active())
	def temp_select_handler(self,widget,data=None):
		dlg = gtk.FileChooserDialog('Select a Temporary File Directory',
		None,gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
		('Cancel',gtk.RESPONSE_CANCEL,'Select',gtk.RESPONSE_OK))
		dlg.set_current_folder(self.options.get_temporary_dir())
		result = dlg.run()
		if result==gtk.RESPONSE_OK:
			self.options.set_temporary_dir(dlg.get_current_folder())
			self.builder.get_object('temp_dir_entry').set_text(self.options.get_temporary_dir())
		dlg.destroy()
	def save_directory_handler(self,widget,data=None):
		dlg = gtk.FileChooserDialog('Select a Default Save Directory',
		None,gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
		('Cancel',gtk.RESPONSE_CANCEL,'Select',gtk.RESPONSE_OK))
		dlg.set_current_folder(self.options.get_save_dir())
		result = dlg.run()
		if result==gtk.RESPONSE_OK:
			self.options.set_save_dir(dlg.get_current_folder())
			self.builder.get_object('save_dir_entry').set_text(self.options.get_save_dir())
		dlg.destroy()
		
	def delay_change_handler(self,widget,data=None):
		self.options.set_recording_delay(widget.get_value_as_int())
    
    def about_handler(self,widget,data=None):
        """Display the about box for tibesti."""
        about = AboutTibestiDialog.AboutTibestiDialog()
        response = about.run()
        about.destroy()
 
    def ok(self, widget, data=None):
        """The user has elected to save the changes.

        Called before the dialog returns gtk.RESONSE_OK from run().
        """

        pass

    def cancel(self, widget, data=None):
        """The user has elected cancel changes.

        Called before the dialog returns gtk.RESPONSE_CANCEL for run()
        """
        # Restore any changes to self._preferences here.
        pass

if __name__ == "__main__":
    dialog = PreferencesTibestiDialog()
    dialog.show()
    gtk.main()
