# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

#needed to find ximagesrc information
import gtk
#gstreamer, for recording
import gst

from tibesti import Options,EncoderOptions

class VideoPipeline(object):
    profiles = {4:{'level':4,'name':'Very Low','framerate':'6'},
    3:{'level':3,'name':'Low','framerate':'10'},
    2:{'level':2,'name':'Default','framerate':'15'}, 
    1:{'level':1,'name':'High','framerate':'20'}, 
    0:{'level':0,'name':'Very High','framerate':'30'}
    }
    def __init__(self):
        self.options = Options.OptionsStore()
        self.optimizer = EncoderOptions.EncoderOptions()
        self.capture_strategy = self._get_capture_strategy()
        
    def _get_capture_strategy(self):
        if self.options.get_capture_type() == 'fullscreen':
            return FullscreenVideoSource()
        else:
            return BoundedVideoSource()

    def _video_source(self):
            self.capture_strategy.current_profile = self.current_profile
            return self.capture_strategy.source()
    
    def _video_filters(self):
        return self.capture_strategy.filters()
    
    def video_encoder(self):
        #Setup the Video Encoder
            encoder_and_options = self.options.get_video_encoder() + ' '
            encoder_and_options += self.optimizer.get_optimization(
                self.options.get_video_encoder(),
                self.options.get_quality())
            return encoder_and_options

    def video(self):
        self.current_profile = self.profiles[self.options.get_quality()]
        #Uppermost video funtion
        return '%s ! %s ! %s ! queue' % (self._video_source(),self._video_filters(),self.video_encoder())

class VideoSource:
    def __init__(self):
        self.options = Options.OptionsStore()
        self.screen = gtk.EventBox().get_screen()
        
    def source(self):
        base = 'ximagesrc name=videopipe '
        screen_parameters = (self.screen.get_display().get_name(),self.screen.get_number())
        base += 'display-name=%s screen-num=%s' % (screen_parameters[0],screen_parameters[1])
        base += ' use-damage=false'
        if not self.options.get_include_pointer():
            base+= ' show-pointer=false'
        d=self.dimensions
        base += ' startx=%s starty=%s endx=%s endy=%s' % (d[0],d[1],d[2],d[3])  
        return base
        
    def filters(self):
        #Video filters getting the video from a source to a usable format
        base='video/x-raw-rgb,framerate=%s/1' % (self.current_profile['framerate'])
        base += ' ! videorate ! ffmpegcolorspace ! videoscale method=1 ! video/x-raw-yuv'
        #TODO this will break on Python 3.0
        width = (self.dimensions[2]-self.dimensions[0])/16*16
        if width != (self.dimensions[2]-self.dimensions[0]):
            width+=16
        height = (self.dimensions[3]-self.dimensions[1])/16*16
        if height != (self.dimensions[2]-self.dimensions[0]):
            height+=16
        base+= ',width=%s,height=%s' % (width,height)

        base+=',framerate=%s/1' % (self.current_profile['framerate'])    
        return base
        
class FullscreenVideoSource(VideoSource):
    def __init__(self):
        self.options = Options.OptionsStore()
        self.screen = gtk.EventBox().get_screen()        
        self.dimensions = [0,0,self.screen.get_width(),self.screen.get_height()]
        
    
class BoundedVideoSource(VideoSource):
    def __init__(self):
        self.options = Options.OptionsStore()
        self.screen = gtk.EventBox().get_screen()
        self.dimensions = self.options.get_capture_area()
