# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

#Zeitgeist is a desktop activity logging system.
#It allows applications to create events or read events from themselves or other applications
#It was split out into its own class in 1.2 because TibestiWindow had become a god class
try:
	from zeitgeist import datamodel,client
	zeitgeist_available=True
except:
	zeitgeist_available = False

from tibesti import Options
class ZeitgeistConnection:
    def __init__(self):
        global zeitgeist_available
        zeitgeist_conn = None
		if zeitgeist_available:
            self.zeitgeist_conn = client.ZeitgeistClient()
		else:
            self.zeitgeist_conn = None
		
		self.options = Options.OptionsStore()
         
    def log_video(self,save_file,mimetype):
        if self.zeitgeist_conn:
            file_name = save_file.rsplit('/',1)[1]
            folder = save_file.rsplit('/',1)[0]
            file_uri = save_file
            zg_subject = datamodel.Subject().new_for_values(
                uri=file_uri,
                interpretation='http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#Video',
                manifestation='http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#FileDataObject',
                origin=folder,
                mimetype=self.options.get_mime_type(),
                text=file_name)
            zg_event=datamodel.Event().new_for_values(
                interpretation='http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#ModifyEvent',
                manifestation='http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#UserActivity',
                actor='application://tibesti.desktop',
                subjects=[zg_subject])
            self.zeitgeist_conn.insert_event(zg_event)
        
    def log_multi(self,data=None):
        for pair in data:
            self.log_video(pair[0],pair[1])

    def active(self):
        return (zeitgeist_conn != None)
