#!/usr/bin/python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 <Andrew C Sellers> <andrew@andrewcsellers.com>
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
### END LICENSE

"""Code to add AppIndicator."""

import gtk
import glib
from tibesti.helpers import get_media_file

import gettext
from gettext import gettext as _
gettext.textdomain('tibesti')

import appindicator

class Indicator:
    def __init__(self,window):
        self.indicator = appindicator.Indicator('tibesti','gsd-xrandr',appindicator.CATEGORY_APPLICATION_STATUS)
        self.indicator.set_status(appindicator.STATUS_ACTIVE)
		self.window = window
        #Can use self.icon once appindicator python api supports custom icons.
        #self.indicator.set_icon("gsb-xrandr")
 
        #Uncomment and choose an icon for attention state. 
        #self.indicator.set_attention_icon("ICON-NAME")
        
        self.menu = gtk.Menu()
        # Add items to Menu and connect signals. 
        # Can access methods from bin/tibesti using window
        
        #Adding preferences button 
        #window represents the main Window object of your app
        self.start_item = gtk.MenuItem("Start Recording")
        self.start_item.connect("activate",window.record_toggle)
        self.start_item.show()
        self.menu.append(self.start_item)

		self.options_item = gtk.MenuItem("Options")
		self.options_item.connect("activate",window.preferences)
		self.options_item.show()
		self.menu.append(self.options_item)
		
        self.quit = gtk.MenuItem("Quit")
        self.quit.connect("activate",window.quit)
        self.quit.show()
        self.menu.append(self.quit)

        self.menu.show()
        self.indicator.set_menu(self.menu)

	def countdown(self,seconds):
		if seconds == 0:
			self.percentage = 0
			self.icon_callback()
			return
		timeout_msecs = seconds * 1000 / 20
		self.percentage = 100
		self.seconds = seconds - 1
        self.icon_callback()
        glib.timeout_add(timeout_msecs,self.icon_callback)        

	def icon_callback(self):
		self.indicator.set_icon("brasero-disc-%s" % (self.percentage))
		self.percentage -=5
		if self.percentage < 5:
			self.indicator.set_icon('gtk-media-record')
			self.start_item.destroy()
			self.start_item = gtk.MenuItem("Stop Recording")
			self.start_item.connect("activate",self.window.record_toggle)
			self.start_item.show()
			self.menu.prepend(self.start_item)			
			return False
		return True
			
		
	def reset_icon(self):
		self.indicator.set_icon("gsd-xrandr")
		self.start_item.destroy()
		self.start_item = gtk.MenuItem("Start Recording")
		self.start_item.connect("activate",self.window.record_toggle)
		self.start_item.show()
		self.menu.prepend(self.start_item)	
            
def new_application_indicator(window):
    ind = Indicator(window)
    return ind
